# Cipher(asymmetric)

## The POG python encryption and decryption CLI utility

Cipher is a python CLI utility for asymmetric file encryption and decryption using the cryptography module.

## Installation and usage

### Windows
```sh
# Installation(pypi)
pip install cipher-asymmetric

# Instalation(git)
pip install git+https://github.com/Programming-geek582/cipher-asymmetric.git

# Usage
cipher or python -m cipher
```

### Linux and mac
```sh
# Installation(pypi)
pip3 install cipher-asymmetric

# Instalation(git)
pip3 install git+https://github.com/Programming-geek582/cipher-asymmetric.git

# Usage
cipher or python3 -m cipher
```

Features:


- File encryption/decryption
- Asymmetric encryption with use of pem files to store the private and public key

*Note: do pip uninstall cipher-symmetric before installing cipher-asymmetric since it might cause a collision between the two libraries*

Happy encrypting!